@@ -22,35 +22,18 @@
 #Importe
 
 import sys
-import time
 import kissen
-import pygame
 import random
 import osso
 import dbus
-#from PyQt4.phonon import Phonon
-#import logging
 import webbrowser
 import subprocess
+from PyQt4.phonon import Phonon
 from PyQt4 import QtGui
 from PyQt4.uic import loadUi
 
-
-#Initialisierung der Module Pygame und Random
-
-pygame.init()
 random.seed()
 
-
-#Logger einrichten
-#logging.basicConfig(filename = "fartyprotokoll.log",
-#                    level = logging.INFO,
-#                    format = "%(asctime)s [%(levelname)-8s] %(message)s")
-
-
-#Erstellen der Mainklasse
-
-
 class MainWindow(QtGui.QMainWindow):
     def __init__(self, parent=None):
         QtGui.QMainWindow.__init__(self,parent)
@@ -76,6 +59,11 @@ class MainWindow(QtGui.QMainWindow):
         self.ui.wolke2.hide()
         self.ui.wolke3.hide()
         self.ui.checkedButton.hide()
+        
+        
+        self.m_media = Phonon.MediaObject(self)
+        audioOutput = Phonon.AudioOutput(Phonon.MusicCategory, self)
+        Phonon.createPath(self.m_media, audioOutput)
        
         #Zuordnung der Buttons mit Verweis auf deren Methoden
        
@@ -97,30 +85,22 @@ class MainWindow(QtGui.QMainWindow):
         self.ui.checkedButton.hide()
         self.ui.checkButton.show()
         self.ui.checkButton.setChecked(False)
-        
-            
-
-        #Methoden
+        self.k
        
     def fartrandom(self):#Zufallsmechanismus für Abspielen der Furzsounds 10-81 
         
         if self.ui.checkButton.isChecked():
-            print"Vibration"
-            pass
-            print "checked"
             for _ in range(2):
                 self.rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,
                                  self._VIBRATE,rpc_args=(self._VIBRATE_PATTERN,"",""),use_system_bus=True)
         else:
-            print"noVibration"
-            pass     
+            pass  
+           
         fartnumber=random.randint(10,81)
         path="/opt/farty/Furzsounds/furz0"+str(fartnumber)+".wav"
-        sound=pygame.mixer.Sound(path)
-        sound.play()
-        pygame.time.delay(200)
-
-       
+        self.m_media.setCurrentSource(Phonon.MediaSource(path))
+        self.m_media.play()
+   
     def closefunc(self):#Methode zum Schließen des Mainwindows
         sys.exit()
         
@@ -139,11 +119,7 @@ class MainWindow(QtGui.QMainWindow):
         
     def aboutfunc(self):
         QtGui.QMessageBox.aboutQt(self) 
-        
-       
-   
-       
-                            
+                          
     
 app = QtGui.QApplication(sys.argv)
 main = MainWindow()
